@@ -789,7 +789,7 @@ namespace Tomboy
 
 		// Reload note data from a complete note XML string
 		// Should referesh note window, too
-		public void LoadForeignNoteXml (string foreignNoteXml, ChangeType changeType)
+		public void LoadForeignNoteXml (string foreignNoteXml)
 		{
 			if (foreignNoteXml == null)
 				throw new ArgumentNullException ("foreignNoteXml");
@@ -852,8 +852,7 @@ namespace Tomboy
 
 			xml.Close ();
 
-			// Allow method caller to specify ChangeType (mostly needed by sync)
-			QueueSave (changeType);
+			// TODO: Any reason to queue a save here?  Maybe not for sync but for others?
 		}
 
 		// TODO: CODE DUPLICATION SUCKS
