@@ -39,18 +39,21 @@ namespace Tomboy
 		public const string SYNC_CONFIGURED_CONFLICT_BEHAVIOR = "/apps/tomboy/sync/sync_conflict_behavior";
 
 		public const string INSERT_TIMESTAMP_FORMAT = "/apps/tomboy/insert_timestamp/format";
+		
+		// TODO: Convert these into properly localized settings in 0.11.x after freeze is lifted
+		public const string SEARCH_WINDOW_X_POS = "/apps/tomboy/search_window_x_pos";
+		public const string SEARCH_WINDOW_Y_POS = "/apps/tomboy/search_window_y_pos";
+		public const string SEARCH_WINDOW_WIDTH = "/apps/tomboy/search_window_width";
+		public const string SEARCH_WINDOW_HEIGHT = "/apps/tomboy/search_window_height";
 
-		static GConf.Client client;
-		static GConf.NotifyEventHandler changed_handler;
+		static IPreferencesClient client;
 
-		public static GConf.Client Client
+		public static IPreferencesClient Client
 		{
 			get {
 				if (client == null) {
-					client = new GConf.Client ();
-
-					changed_handler = new GConf.NotifyEventHandler (OnSettingChanged);
-					client.AddNotify ("/apps/tomboy", changed_handler);
+					client = Services.Preferences;
+					client.AddNotify ("/apps/tomboy", OnSettingChanged);
 				}
 				return client;
 			}
@@ -138,7 +141,7 @@ namespace Tomboy
 		{
 			try {
 				return Client.Get (key);
-			} catch (GConf.NoSuchKeyException) {
+			} catch (NoSuchKeyException) {
 				object default_val = GetDefault (key);
 
 				if (default_val != null)
@@ -153,9 +156,9 @@ namespace Tomboy
 			Client.Set (key, value);
 		}
 
-		public static event GConf.NotifyEventHandler SettingChanged;
+		public static event NotifyEventHandler SettingChanged;
 
-		static void OnSettingChanged (object sender, GConf.NotifyEventArgs args)
+		static void OnSettingChanged (object sender, NotifyEventArgs args)
 		{
 			if (SettingChanged != null) {
 				SettingChanged (sender, args);
