@@ -191,7 +191,9 @@ namespace Tomboy
                         // Use another VBox to place the MenuBar
                         // right at thetop of the window.
                         content_vbox = new Gtk.VBox (false, 0);
+#if !MAC
                         content_vbox.PackStart (menu_bar, false, false, 0);
+#endif
                         content_vbox.PackStart (vbox, true, true, 0);
                         content_vbox.Show ();
 
@@ -962,9 +964,10 @@ namespace Tomboy
                         Hide ();
                         Destroy ();
                         instance = null;
-
+#if !MAC
                         if (Tomboy.TrayIconShowing == false)
                                 Tomboy.ActionManager ["QuitTomboyAction"].Activate ();
+#endif
                 }
 
                 void OnDelete (object sender, Gtk.DeleteEventArgs args)
@@ -1283,7 +1286,8 @@ namespace Tomboy
 			Gtk.TreeModel model;
 			Gtk.TreeIter iter;
 			
-			if (notebooksTree.Selection.GetSelected (out model, out iter) == false)
+			Gtk.TreeSelection selection = notebooksTree.Selection;
+			if (selection == null || selection.GetSelected (out model, out iter) == false)
 				return null; // Nothing selected
 			
 			return model.GetValue (iter, 0) as Notebooks.Notebook;
@@ -1369,6 +1373,10 @@ namespace Tomboy
                 public string SearchText
                 {
                         get {
+				// Entry may be null if search window closes
+				// early (bug #544996).
+				if (find_combo == null || find_combo.Entry == null)
+					return null;
                                 string text = find_combo.Entry.Text;
                                 text = text.Trim ();
                                 if (text == String.Empty)
