@@ -14,18 +14,18 @@ namespace Tomboy.Sync
 		private Gtk.Label messageLabel;
 		private Gtk.ProgressBar progressBar;
 		private Gtk.Label progressLabel;
-		
+
 		private Gtk.Expander expander;
 		private Gtk.Button closeButton;
 		private uint progressBarTimeoutId;
-		
+
 		private Gtk.TreeStore model;
-		
+
 		// TODO: Possible to make Tomboy not crash if quit while dialog is up?
 		public SyncDialog ()
-			: base (string.Empty, 
-					null,
-					Gtk.DialogFlags.DestroyWithParent)
+: base (string.Empty,
+		        null,
+		        Gtk.DialogFlags.DestroyWithParent)
 		{
 			progressBarTimeoutId = 0;
 
@@ -90,7 +90,7 @@ namespace Tomboy.Sync
 			expander.Spacing = 6;
 			expander.Activated += OnExpanderActivated;
 			expander.Show ();
-			outerVBox.PackStart (expander, true, true, 0);			
+			outerVBox.PackStart (expander, true, true, 0);
 
 			// Contents of expander
 			Gtk.VBox expandVBox = new Gtk.VBox ();
@@ -116,15 +116,15 @@ namespace Tomboy.Sync
 
 			// Set up TreeViewColumns
 			Gtk.TreeViewColumn column = new Gtk.TreeViewColumn (
-			Catalog.GetString ("Note Title"),
-			new Gtk.CellRendererText (), "text", 0);
+			        Catalog.GetString ("Note Title"),
+			        new Gtk.CellRendererText (), "text", 0);
 			column.SortColumnId = 0;
 			column.Resizable = true;
 			treeView.AppendColumn (column);
 
 			column = new Gtk.TreeViewColumn (
-			Catalog.GetString ("Status"),
-			new Gtk.CellRendererText (), "text", 1);
+			        Catalog.GetString ("Status"),
+			        new Gtk.CellRendererText (), "text", 1);
 			column.SortColumnId = 1;
 			column.Resizable = true;
 			treeView.AppendColumn (column);
@@ -133,7 +133,7 @@ namespace Tomboy.Sync
 			closeButton = (Gtk.Button) AddButton (Gtk.Stock.Close, Gtk.ResponseType.Close);
 			closeButton.Sensitive = false;
 		}
-		
+
 		public override void Destroy ()
 		{
 			SyncManager.StateChanged -= OnSyncStateChanged;
@@ -141,11 +141,11 @@ namespace Tomboy.Sync
 			SyncManager.NoteConflictDetected -= OnNoteConflictDetected;
 			base.Destroy ();
 		}
-		
+
 		protected override void OnRealized ()
 		{
 			base.OnRealized ();
-			
+
 			SyncManager.StateChanged += OnSyncStateChanged;
 			SyncManager.NoteSynchronized += OnNoteSynchronized;
 			SyncManager.NoteConflictDetected += OnNoteConflictDetected;
@@ -154,7 +154,7 @@ namespace Tomboy.Sync
 			if (state == SyncState.Idle) {
 				// Kick off a timer to keep the progress bar going
 				progressBarTimeoutId = GLib.Timeout.Add (500, OnPulseProgressBar);
-			
+
 				// Kick off a new synchronization
 				SyncManager.PerformSynchronization ();
 			} else {
@@ -162,7 +162,7 @@ namespace Tomboy.Sync
 				OnSyncStateChanged (state);
 			}
 		}
-		
+
 		private void OnExpanderActivated (object sender, EventArgs e)
 		{
 			if (expander.Expanded)
@@ -175,40 +175,44 @@ namespace Tomboy.Sync
 		{
 			// TODO: Store GUID hidden in model; use instead of title
 			Gtk.TreeIter iter;
-			if (!model.GetIter (out iter, args.Path)) 
+			if (!model.GetIter (out iter, args.Path))
 				return;
 
 			string noteTitle = (string) model.GetValue (iter, 0 /* note title */);
-			
-			Note note = Tomboy.DefaultNoteManager.Find (noteTitle); 
+
+			Note note = Tomboy.DefaultNoteManager.Find (noteTitle);
 			if (note != null)
 				note.Window.Present ();
 		}
-		
+
 		public string HeaderText
 		{
 			set {
 				headerLabel.Markup = string.Format (
-					"<span size=\"large\" weight=\"bold\">{0}</span>",
-					value);
+				        "<span size=\"large\" weight=\"bold\">{0}</span>",
+				        value);
 			}
 		}
-		
+
 		public string MessageText
 		{
-			set { messageLabel.Text = value; }
-		}
-		
-		public string ProgressText
-		{
-			get { return progressLabel.Text; }
 			set {
-				progressLabel.Markup =
-					string.Format ("<span style=\"italic\">{0}</span>",
-						value);
+				messageLabel.Text = value;
 			}
 		}
-		
+
+		public string ProgressText
+		{
+			get {
+				return progressLabel.Text;
+			}
+			set {
+				progressLabel.Markup =
+				        string.Format ("<span style=\"italic\">{0}</span>",
+				                       value);
+			}
+		}
+
 		public void AddUpdateItem (string title, string status)
 		{
 			model.AppendValues (title, status);
@@ -219,9 +223,9 @@ namespace Tomboy.Sync
 		{
 			if (SyncManager.State == SyncState.Idle)
 				return false;
-			
+
 			progressBar.Pulse ();
-			
+
 			// Return true to keep things going well
 			return true;
 		}
@@ -292,12 +296,12 @@ namespace Tomboy.Sync
 					Title = Catalog.GetString ("Synchronization Complete");
 					HeaderText = Catalog.GetString ("Synchronization is complete");
 					string numNotesUpdated =
-						string.Format (Catalog.GetPluralString ("{0} note updated.",
-						                                        "{0} notes updated.",
-						                                        count),
-						               count);
+					        string.Format (Catalog.GetPluralString ("{0} note updated.",
+					                                                "{0} notes updated.",
+					                                                count),
+					                       count);
 					MessageText = numNotesUpdated + "  " +
-						Catalog.GetString ("Your notes are now up to date.");
+					              Catalog.GetString ("Your notes are now up to date.");
 					ProgressText = string.Empty;
 					break;
 				case SyncState.UserCancelled:
@@ -321,7 +325,7 @@ namespace Tomboy.Sync
 				}
 			});
 		}
-		
+
 		void OnNoteSynchronized (string noteTitle, NoteSyncType type)
 		{
 			// This event handler will be called by the synchronization thread
@@ -353,7 +357,7 @@ namespace Tomboy.Sync
 				AddUpdateItem (noteTitle, statusText);
 			});
 		}
-		
+
 		void OnNoteConflictDetected (NoteManager manager,
 		                             Note localConflictNote,
 		                             NoteUpdate remoteNote,
@@ -363,7 +367,7 @@ namespace Tomboy.Sync
 			object dlgBehaviorPref = Preferences.Get (Preferences.SYNC_CONFIGURED_CONFLICT_BEHAVIOR);
 			if (dlgBehaviorPref != null && dlgBehaviorPref is int) // TODO: Check range of this int
 				savedBehavior = (SyncTitleConflictResolution)dlgBehaviorPref;
-			
+
 			SyncTitleConflictResolution resolution = SyncTitleConflictResolution.OverwriteExisting;
 			// This event handler will be called by the synchronization thread
 			// so we have to use the delegate here to manipulate the GUI.
@@ -372,59 +376,59 @@ namespace Tomboy.Sync
 			Exception mainThreadException = null;
 			Gtk.Application.Invoke (delegate {
 				try {
-				SyncTitleConflictDialog conflictDlg =
+					SyncTitleConflictDialog conflictDlg =
 					new SyncTitleConflictDialog (localConflictNote, noteUpdateTitles);
-				Gtk.ResponseType reponse = Gtk.ResponseType.Ok;
-				
-				bool noteSyncBitsMatch =
-					SyncManager.SynchronizedNoteXmlMatches (localConflictNote.GetCompleteNoteXml (),
-					                                        remoteNote.XmlContent);
-				
-				// If the synchronized note content is in conflict
-				// and there is no saved conflict handling behavior, show the dialog
-				if (!noteSyncBitsMatch && savedBehavior == 0)
-					reponse = (Gtk.ResponseType) conflictDlg.Run ();
-					
-				
-				if (reponse == Gtk.ResponseType.Cancel)
-					resolution = SyncTitleConflictResolution.Cancel;
-				else {
-					if (noteSyncBitsMatch)
-						resolution = SyncTitleConflictResolution.OverwriteExisting;
-					else if (savedBehavior == 0)
-						resolution = conflictDlg.Resolution;
-					else
-						resolution = savedBehavior;
+					Gtk.ResponseType reponse = Gtk.ResponseType.Ok;
 
-					switch (resolution) {
-					case SyncTitleConflictResolution.OverwriteExisting:
-						if (conflictDlg.AlwaysPerformThisAction)
-							savedBehavior = resolution;
-						// No need to delete if sync will overwrite
-						if (localConflictNote.Id != remoteNote.UUID)
-							manager.Delete (localConflictNote);
-						break;
-					case SyncTitleConflictResolution.RenameExistingAndUpdate:
-						if (conflictDlg.AlwaysPerformThisAction)
-							savedBehavior = resolution;
-						RenameNote (localConflictNote, conflictDlg.RenamedTitle, true);
-						break;
-					case SyncTitleConflictResolution.RenameExistingNoUpdate:
-						if (conflictDlg.AlwaysPerformThisAction)
-							savedBehavior = resolution;
-						RenameNote (localConflictNote, conflictDlg.RenamedTitle, false);
-						break;
+					bool noteSyncBitsMatch =
+					        SyncManager.SynchronizedNoteXmlMatches (localConflictNote.GetCompleteNoteXml (),
+					                                                remoteNote.XmlContent);
+
+					// If the synchronized note content is in conflict
+					// and there is no saved conflict handling behavior, show the dialog
+					if (!noteSyncBitsMatch && savedBehavior == 0)
+						reponse = (Gtk.ResponseType) conflictDlg.Run ();
+
+
+					if (reponse == Gtk.ResponseType.Cancel)
+						resolution = SyncTitleConflictResolution.Cancel;
+					else {
+						if (noteSyncBitsMatch)
+							resolution = SyncTitleConflictResolution.OverwriteExisting;
+						else if (savedBehavior == 0)
+							resolution = conflictDlg.Resolution;
+						else
+							resolution = savedBehavior;
+
+						switch (resolution) {
+						case SyncTitleConflictResolution.OverwriteExisting:
+							if (conflictDlg.AlwaysPerformThisAction)
+								savedBehavior = resolution;
+							// No need to delete if sync will overwrite
+							if (localConflictNote.Id != remoteNote.UUID)
+								manager.Delete (localConflictNote);
+							break;
+						case SyncTitleConflictResolution.RenameExistingAndUpdate:
+							if (conflictDlg.AlwaysPerformThisAction)
+								savedBehavior = resolution;
+							RenameNote (localConflictNote, conflictDlg.RenamedTitle, true);
+							break;
+						case SyncTitleConflictResolution.RenameExistingNoUpdate:
+							if (conflictDlg.AlwaysPerformThisAction)
+								savedBehavior = resolution;
+							RenameNote (localConflictNote, conflictDlg.RenamedTitle, false);
+							break;
+						}
 					}
-				}
-				
-				Preferences.Set (Preferences.SYNC_CONFIGURED_CONFLICT_BEHAVIOR,
-				                 (int) savedBehavior); // TODO: Clean up
-				
-				conflictDlg.Hide ();
-				conflictDlg.Destroy ();
-			
-				// Let the SyncManager continue
-				SyncManager.ResolveConflict (/*localConflictNote, */resolution);
+
+					Preferences.Set (Preferences.SYNC_CONFIGURED_CONFLICT_BEHAVIOR,
+					                 (int) savedBehavior); // TODO: Clean up
+
+					conflictDlg.Hide ();
+					conflictDlg.Destroy ();
+
+					// Let the SyncManager continue
+					SyncManager.ResolveConflict (/*localConflictNote, */resolution);
 				} catch (Exception e) {
 					mainThreadException = e;
 				}
@@ -434,8 +438,8 @@ namespace Tomboy.Sync
 		}
 
 		#endregion // Private Event Handlers
-		
-#region Private Methods
+
+		#region Private Methods
 		// TODO: This appears to add <link:internal> around the note title
 		//       in the content.
 		private void RenameNote (Note note, string newTitle, bool updateReferencingNotes)
@@ -443,9 +447,9 @@ namespace Tomboy.Sync
 			string oldTitle = note.Title;
 			// Rename the note (skip for now...never using updateReferencingNotes option)
 			//if (updateReferencingNotes) // NOTE: This might never work, or lead to a ton of conflicts
-			//	note.Title = newTitle;
+			// note.Title = newTitle;
 			//else
-			//	note.RenameWithoutLinkUpdate (newTitle);
+			// note.RenameWithoutLinkUpdate (newTitle);
 			//string oldContent = note.XmlContent;
 			//note.XmlContent = NoteArchiver.Instance.GetRenamedNoteXml (oldContent, oldTitle, newTitle);
 
@@ -453,28 +457,28 @@ namespace Tomboy.Sync
 			note.Save (); // Write to file
 			bool noteOpen = note.IsOpened;
 			string newContent = //note.XmlContent;
-				NoteArchiver.Instance.GetRenamedNoteXml (note.XmlContent, oldTitle, newTitle);
+			        NoteArchiver.Instance.GetRenamedNoteXml (note.XmlContent, oldTitle, newTitle);
 			string newCompleteContent = //note.GetCompleteNoteXml ();
-				NoteArchiver.Instance.GetRenamedNoteXml (note.GetCompleteNoteXml (), oldTitle, newTitle);
+			        NoteArchiver.Instance.GetRenamedNoteXml (note.GetCompleteNoteXml (), oldTitle, newTitle);
 			//Logger.Debug ("RenameNote: newContent: " + newContent);
 			//Logger.Debug ("RenameNote: newCompleteContent: " + newCompleteContent);
-			
+
 			// We delete and recreate the note to simplify content conflict handling
 			Tomboy.DefaultNoteManager.Delete (note);
-			
+
 			// Create note with old XmlContent just in case GetCompleteNoteXml failed
 			Logger.Debug ("RenameNote: about to create " + newTitle);
 			Note renamedNote = Tomboy.DefaultNoteManager.Create (newTitle, newContent);
 			if (newCompleteContent != null) {// TODO: Anything to do if it is null?
 				try {
 					renamedNote.LoadForeignNoteXml (newCompleteContent);
-				} catch {} // TODO: Handle exception in case that newCompleteContent is invalid XML 
+				} catch {} // TODO: Handle exception in case that newCompleteContent is invalid XML
 			}
-			if (noteOpen)
+		if (noteOpen)
 				renamedNote.Window.Present ();
 		}
-#endregion // Private Methods
-		
+		#endregion // Private Methods
+
 	}
 
 
@@ -482,48 +486,48 @@ namespace Tomboy.Sync
 	{
 		private Note existingNote;
 		private IList<string> noteUpdateTitles;
-		
+
 		private Gtk.Button continueButton;
-		
+
 		private Gtk.Entry renameEntry;
 		private Gtk.CheckButton renameUpdateCheck;
 		private Gtk.RadioButton renameRadio;
 		private Gtk.RadioButton deleteExistingRadio;
 		private Gtk.CheckButton alwaysDoThisCheck;
-		
+
 		private Gtk.Label headerLabel;
 		private Gtk.Label messageLabel;
 
-		public SyncTitleConflictDialog (Note existingNote, IList<string> noteUpdateTitles) :
-			base (Catalog.GetString ("Note Conflict"), null, Gtk.DialogFlags.Modal)
+public SyncTitleConflictDialog (Note existingNote, IList<string> noteUpdateTitles) :
+		base (Catalog.GetString ("Note Conflict"), null, Gtk.DialogFlags.Modal)
 		{
 			this.existingNote = existingNote;
 			this.noteUpdateTitles = noteUpdateTitles;
-			
+
 			// Suggest renaming note by appending " (old)" to the existing title
 			string suggestedRenameBase = existingNote.Title + Catalog.GetString (" (old)");
 			string suggestedRename = suggestedRenameBase;
 			for (int i = 1; !IsNoteTitleAvailable (suggestedRename); i++)
 				suggestedRename = suggestedRenameBase + " " + i.ToString();
-			
+
 			VBox outerVBox = new VBox (false, 12);
 			outerVBox.BorderWidth = 12;
 			outerVBox.Spacing = 8;
-			
+
 			HBox hbox = new HBox (false, 8);
 			Image image = new Image (GuiUtils.GetIcon (Gtk.Stock.DialogWarning, 48)); // TODO: Is this the right icon?
 			image.Show ();
 			hbox.PackStart (image, false, false, 0);
-			
+
 			VBox vbox = new VBox (false, 8);
-			
+
 			headerLabel = new Label ();
 			headerLabel.UseMarkup = true;
 			headerLabel.Xalign = 0;
 			headerLabel.UseUnderline = false;
 			headerLabel.Show ();
 			vbox.PackStart (headerLabel, false, false, 0);
-			
+
 			messageLabel = new Label ();
 			messageLabel.Xalign = 0;
 			messageLabel.UseUnderline = false;
@@ -531,19 +535,19 @@ namespace Tomboy.Sync
 			messageLabel.Wrap = true;
 			messageLabel.Show ();
 			vbox.PackStart (messageLabel, false, false, 0);
-			
+
 			vbox.Show ();
 			hbox.PackStart (vbox, true, true, 0);
-			
+
 			hbox.Show ();
 			outerVBox.PackStart (hbox);
 			VBox.PackStart (outerVBox);
-			
+
 			Gtk.HBox renameHBox = new Gtk.HBox ();
 			renameRadio = new Gtk.RadioButton (Catalog.GetString ("Rename local note:"));
 			renameRadio.Toggled += radio_Toggled;
 			Gtk.VBox renameOptionsVBox = new Gtk.VBox ();
-			
+
 			renameEntry = new Gtk.Entry (suggestedRename);
 			renameEntry.Changed += renameEntry_Changed;
 			renameUpdateCheck = new Gtk.CheckButton (Catalog.GetString ("Update links in referencing notes"));
@@ -552,40 +556,40 @@ namespace Tomboy.Sync
 			renameHBox.PackStart (renameRadio);
 			renameHBox.PackStart (renameOptionsVBox);
 			VBox.PackStart (renameHBox);
-			
+
 			deleteExistingRadio = new Gtk.RadioButton (renameRadio, Catalog.GetString ("Overwrite local note"));
 			deleteExistingRadio.Toggled += radio_Toggled;
 			VBox.PackStart (deleteExistingRadio);
-			
+
 			alwaysDoThisCheck = new Gtk.CheckButton (Catalog.GetString ("Always perform this action"));
 			VBox.PackStart (alwaysDoThisCheck);
-			
+
 			continueButton = (Gtk.Button) AddButton (Gtk.Stock.GoForward, Gtk.ResponseType.Accept);
-			
+
 			// Set initial dialog text
 			HeaderText = Catalog.GetString ("Note conflict detected");
 			MessageText = string.Format (Catalog.GetString ("The server version of \"{0}\" conflicts with your local note."
-			                                                + "  What do you want to do with your local note?"),
+			                             + "  What do you want to do with your local note?"),
 			                             existingNote.Title);
-			
+
 			ShowAll ();
 		}
-		
+
 		private void renameEntry_Changed (object sender, System.EventArgs e)
 		{
 			if (renameRadio.Active &&
-			    !IsNoteTitleAvailable (RenamedTitle))
+			                !IsNoteTitleAvailable (RenamedTitle))
 				continueButton.Sensitive = false;
 			else
 				continueButton.Sensitive = true;
 		}
-		
+
 		private bool IsNoteTitleAvailable (string renamedTitle)
 		{
 			return !noteUpdateTitles.Contains (renamedTitle) &&
-				existingNote.Manager.Find (renamedTitle) == null;
+			       existingNote.Manager.Find (renamedTitle) == null;
 		}
-		
+
 		// Handler for each radio button's Toggled event
 		private void radio_Toggled (object sender, System.EventArgs e)
 		{
@@ -596,38 +600,44 @@ namespace Tomboy.Sync
 			renameEntry.Sensitive = renameRadio.Active;
 			renameUpdateCheck.Sensitive = renameRadio.Active;
 		}
-		
+
 		public string HeaderText
 		{
 			set {
 				headerLabel.Markup = string.Format (
-					"<span size=\"large\" weight=\"bold\">{0}</span>",
-					value);
+				        "<span size=\"large\" weight=\"bold\">{0}</span>",
+				        value);
 			}
 		}
-		
+
 		public string MessageText
 		{
-			set { messageLabel.Text = value; }
+			set {
+				messageLabel.Text = value;
+			}
 		}
-		
+
 		public string RenamedTitle
 		{
-			get { return renameEntry.Text; }
+			get {
+				return renameEntry.Text;
+			}
 		}
-		
+
 		public bool AlwaysPerformThisAction
 		{
-			get { return alwaysDoThisCheck.Active; }
+			get {
+				return alwaysDoThisCheck.Active;
+			}
 		}
-		
+
 		public SyncTitleConflictResolution Resolution
 		{
 			get
 			{
 				if (renameRadio.Active) {
 					if (renameUpdateCheck.Active)
-					        return SyncTitleConflictResolution.RenameExistingAndUpdate;
+						return SyncTitleConflictResolution.RenameExistingAndUpdate;
 					else
 						return SyncTitleConflictResolution.RenameExistingNoUpdate;
 				}
@@ -635,7 +645,7 @@ namespace Tomboy.Sync
 					return SyncTitleConflictResolution.OverwriteExisting;
 			}
 		}
-	}	
+	}
 
 	// NOTE: These enum int values are used to save the default behavior for this dialog
 	public enum SyncTitleConflictResolution
